@@ -1,4 +1,8 @@
 pub const TRANSFER_ENCODING_CHUNKED_VALUE: &str = "chunked";
 
+//
+#[cfg(feature = "stream")]
+pub mod stream;
+
 //
 pub mod utils;
